package com.example.react_native_commonutils_android;

import android.content.Context;
import android.content.pm.PackageInfo;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;

import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;

import java.util.List;

/**
 * Created by sunyihong on 16/9/19.
 */
public class CommonUtilsModule extends ReactContextBaseJavaModule
{
    Context context;

    public CommonUtilsModule(ReactApplicationContext reactContext)
    {
        super(reactContext);

        this.context=reactContext.getApplicationContext();
    }

    @Override
    public String getName() {
        return "CommonUtils";
    }



    /*
    检测可用网络   (注: unknow-未知    wifi-局域网   wwan-蜂窝网络  notReachable-没有网络  )
    isAvailableNetWork(Promise promise)
     */
    @ReactMethod
    public void isAvailableNetWork(Promise promise)
    {
        String netType = "unknow";
        ConnectivityManager connectivityManager = (ConnectivityManager) (this.context.getSystemService(Context.CONNECTIVITY_SERVICE));
        NetworkInfo networkInfo = connectivityManager.getActiveNetworkInfo();

        //没有网络
        if (networkInfo == null) 
        {
            netType="notReachable";

            promise.resolve(netType);

            return ;
        } 

        //有网络
        int nType = networkInfo.getType();
        if (nType == ConnectivityManager.TYPE_MOBILE) 
        {
            netType = "wwan";
        } 
        else if (nType == ConnectivityManager.TYPE_WIFI) 
        {
            netType = "wifi";
        }

        promise.resolve(netType);
    }

    /*
    检测是否安装了微信
    isInstallWeiXinApp(Promise promise)
     */
    @ReactMethod
    public void isInstallWeiXinApp(Promise promise)
    {
        if (getNativeApkVer(this.context,"com.tencent.mm"))
        {
            promise.resolve("true");
        }
        else
        {
            promise.resolve("false");
        }
    }

    /*
    检测是否安装了新浪微博
    isInstallSinaApp(Promise promise)
     */
    @ReactMethod
    public void isInstallSinaApp(Promise promise)
    {
        if (getNativeApkVer(this.context,"com.sina.weibo"))
        {
            promise.resolve("true");
        }
        else if (getNativeApkVer(this.context,"com.sina.weibog3"))
        {
            promise.resolve("true");
        }
        else
        {
            promise.resolve("false");
        }
    }

    /*
    检测是否安装了QQ
    isInstallQQApp(Promise promise)
     */
    @ReactMethod
    public void isInstallQQApp(Promise promise)
    {
        if (getNativeApkVer(this.context,"com.tencent.mobileqq"))
        {
            promise.resolve("true");
        }
        else if (getNativeApkVer(this.context,"com.tencent.qqlite"))
        {
            promise.resolve("true");
        }
        else if (getNativeApkVer(this.context,"com.tencent.minihd.qq"))
        {
            promise.resolve("true");
        }
        else
        {
            promise.resolve("false");
        }
    }

    /*
    检测是否安装了支付宝
    isInstallAliPayApp(Promise promise)
     */
    @ReactMethod
    public void isInstallAliPayApp(Promise promise)
    {
        if (getNativeApkVer(this.context,"com.eg.android.AlipayGphone"))
        {
            promise.resolve("true");
        }
        else
        {
            promise.resolve("false");
        }
    }


    /*
    检测是否安装了某个APP
    isInstallOneApp(String urlStr,Promise promise)
     */
    @ReactMethod
    public void isInstallOneApp(String urlStr,Promise promise)
    {
        if (getNativeApkVer(this.context,urlStr))
        {
            promise.resolve("true");
        }
        else
        {
            promise.resolve("false");
        }
    }







    private static boolean  getNativeApkVer(Context context,String string)
    {
        List<PackageInfo> packages = context.getPackageManager().getInstalledPackages(0);
        for (int i = 0; i < packages.size(); i++)
        {
            PackageInfo packageInfo = packages.get(i);
            String packageName = packageInfo.packageName;

            boolean result=packageName.equals(string);  //packageName.equals("com.tencent.mm");
            if(result)
            {
                return true;
            }
        }
        return false;
    }






}
